# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "3.7.2"

# import apis into sdk package
from pulpcore.client.pulp_python.api.content_packages_api import ContentPackagesApi
from pulpcore.client.pulp_python.api.distributions_pypi_api import DistributionsPypiApi
from pulpcore.client.pulp_python.api.publications_pypi_api import PublicationsPypiApi
from pulpcore.client.pulp_python.api.pypi_api import PypiApi
from pulpcore.client.pulp_python.api.pypi_legacy_api import PypiLegacyApi
from pulpcore.client.pulp_python.api.pypi_metadata_api import PypiMetadataApi
from pulpcore.client.pulp_python.api.pypi_simple_api import PypiSimpleApi
from pulpcore.client.pulp_python.api.remotes_python_api import RemotesPythonApi
from pulpcore.client.pulp_python.api.repositories_python_api import RepositoriesPythonApi
from pulpcore.client.pulp_python.api.repositories_python_versions_api import RepositoriesPythonVersionsApi

# import ApiClient
from pulpcore.client.pulp_python.api_client import ApiClient
from pulpcore.client.pulp_python.configuration import Configuration
from pulpcore.client.pulp_python.exceptions import OpenApiException
from pulpcore.client.pulp_python.exceptions import ApiTypeError
from pulpcore.client.pulp_python.exceptions import ApiValueError
from pulpcore.client.pulp_python.exceptions import ApiKeyError
from pulpcore.client.pulp_python.exceptions import ApiException
# import models into sdk package
from pulpcore.client.pulp_python.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_python.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulp_python.models.exclude_platforms_enum import ExcludePlatformsEnum
from pulpcore.client.pulp_python.models.package_metadata_response import PackageMetadataResponse
from pulpcore.client.pulp_python.models.package_types_enum import PackageTypesEnum
from pulpcore.client.pulp_python.models.package_upload import PackageUpload
from pulpcore.client.pulp_python.models.package_upload_task_response import PackageUploadTaskResponse
from pulpcore.client.pulp_python.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_distribution_response_list import PaginatedpythonPythonDistributionResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_package_content_response_list import PaginatedpythonPythonPackageContentResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_publication_response_list import PaginatedpythonPythonPublicationResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_remote_response_list import PaginatedpythonPythonRemoteResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_repository_response_list import PaginatedpythonPythonRepositoryResponseList
from pulpcore.client.pulp_python.models.patchedpython_python_distribution import PatchedpythonPythonDistribution
from pulpcore.client.pulp_python.models.patchedpython_python_remote import PatchedpythonPythonRemote
from pulpcore.client.pulp_python.models.patchedpython_python_repository import PatchedpythonPythonRepository
from pulpcore.client.pulp_python.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_python.models.python_bander_remote import PythonBanderRemote
from pulpcore.client.pulp_python.models.python_python_distribution import PythonPythonDistribution
from pulpcore.client.pulp_python.models.python_python_distribution_response import PythonPythonDistributionResponse
from pulpcore.client.pulp_python.models.python_python_package_content import PythonPythonPackageContent
from pulpcore.client.pulp_python.models.python_python_package_content_response import PythonPythonPackageContentResponse
from pulpcore.client.pulp_python.models.python_python_publication import PythonPythonPublication
from pulpcore.client.pulp_python.models.python_python_publication_response import PythonPythonPublicationResponse
from pulpcore.client.pulp_python.models.python_python_remote import PythonPythonRemote
from pulpcore.client.pulp_python.models.python_python_remote_response import PythonPythonRemoteResponse
from pulpcore.client.pulp_python.models.python_python_repository import PythonPythonRepository
from pulpcore.client.pulp_python.models.python_python_repository_response import PythonPythonRepositoryResponse
from pulpcore.client.pulp_python.models.repair import Repair
from pulpcore.client.pulp_python.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulp_python.models.repository_sync_url import RepositorySyncURL
from pulpcore.client.pulp_python.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulp_python.models.summary_response import SummaryResponse




# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_python.configuration import Configuration


class PythonPythonPackageContentResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'artifact': 'str',
        'filename': 'str',
        'packagetype': 'str',
        'name': 'str',
        'version': 'str',
        'sha256': 'str',
        'metadata_version': 'str',
        'summary': 'str',
        'description': 'str',
        'description_content_type': 'str',
        'keywords': 'str',
        'home_page': 'str',
        'download_url': 'str',
        'author': 'str',
        'author_email': 'str',
        'maintainer': 'str',
        'maintainer_email': 'str',
        'license': 'str',
        'requires_python': 'str',
        'project_url': 'str',
        'project_urls': 'object',
        'platform': 'str',
        'supported_platform': 'str',
        'requires_dist': 'object',
        'provides_dist': 'object',
        'obsoletes_dist': 'object',
        'requires_external': 'object',
        'classifiers': 'object'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'artifact': 'artifact',
        'filename': 'filename',
        'packagetype': 'packagetype',
        'name': 'name',
        'version': 'version',
        'sha256': 'sha256',
        'metadata_version': 'metadata_version',
        'summary': 'summary',
        'description': 'description',
        'description_content_type': 'description_content_type',
        'keywords': 'keywords',
        'home_page': 'home_page',
        'download_url': 'download_url',
        'author': 'author',
        'author_email': 'author_email',
        'maintainer': 'maintainer',
        'maintainer_email': 'maintainer_email',
        'license': 'license',
        'requires_python': 'requires_python',
        'project_url': 'project_url',
        'project_urls': 'project_urls',
        'platform': 'platform',
        'supported_platform': 'supported_platform',
        'requires_dist': 'requires_dist',
        'provides_dist': 'provides_dist',
        'obsoletes_dist': 'obsoletes_dist',
        'requires_external': 'requires_external',
        'classifiers': 'classifiers'
    }

    def __init__(self, pulp_href=None, pulp_created=None, artifact=None, filename=None, packagetype=None, name=None, version=None, sha256='', metadata_version=None, summary=None, description=None, description_content_type=None, keywords=None, home_page=None, download_url=None, author=None, author_email=None, maintainer=None, maintainer_email=None, license=None, requires_python=None, project_url=None, project_urls=None, platform=None, supported_platform=None, requires_dist=None, provides_dist=None, obsoletes_dist=None, requires_external=None, classifiers=None, local_vars_configuration=None):  # noqa: E501
        """PythonPythonPackageContentResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._artifact = None
        self._filename = None
        self._packagetype = None
        self._name = None
        self._version = None
        self._sha256 = None
        self._metadata_version = None
        self._summary = None
        self._description = None
        self._description_content_type = None
        self._keywords = None
        self._home_page = None
        self._download_url = None
        self._author = None
        self._author_email = None
        self._maintainer = None
        self._maintainer_email = None
        self._license = None
        self._requires_python = None
        self._project_url = None
        self._project_urls = None
        self._platform = None
        self._supported_platform = None
        self._requires_dist = None
        self._provides_dist = None
        self._obsoletes_dist = None
        self._requires_external = None
        self._classifiers = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if artifact is not None:
            self.artifact = artifact
        if filename is not None:
            self.filename = filename
        if packagetype is not None:
            self.packagetype = packagetype
        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if sha256 is not None:
            self.sha256 = sha256
        if metadata_version is not None:
            self.metadata_version = metadata_version
        if summary is not None:
            self.summary = summary
        if description is not None:
            self.description = description
        if description_content_type is not None:
            self.description_content_type = description_content_type
        if keywords is not None:
            self.keywords = keywords
        if home_page is not None:
            self.home_page = home_page
        if download_url is not None:
            self.download_url = download_url
        if author is not None:
            self.author = author
        if author_email is not None:
            self.author_email = author_email
        if maintainer is not None:
            self.maintainer = maintainer
        if maintainer_email is not None:
            self.maintainer_email = maintainer_email
        if license is not None:
            self.license = license
        if requires_python is not None:
            self.requires_python = requires_python
        if project_url is not None:
            self.project_url = project_url
        if project_urls is not None:
            self.project_urls = project_urls
        if platform is not None:
            self.platform = platform
        if supported_platform is not None:
            self.supported_platform = supported_platform
        if requires_dist is not None:
            self.requires_dist = requires_dist
        if provides_dist is not None:
            self.provides_dist = provides_dist
        if obsoletes_dist is not None:
            self.obsoletes_dist = obsoletes_dist
        if requires_external is not None:
            self.requires_external = requires_external
        if classifiers is not None:
            self.classifiers = classifiers

    @property
    def pulp_href(self):
        """Gets the pulp_href of this PythonPythonPackageContentResponse.  # noqa: E501


        :return: The pulp_href of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this PythonPythonPackageContentResponse.


        :param pulp_href: The pulp_href of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this PythonPythonPackageContentResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this PythonPythonPackageContentResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def artifact(self):
        """Gets the artifact of this PythonPythonPackageContentResponse.  # noqa: E501

        Artifact file representing the physical content  # noqa: E501

        :return: The artifact of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this PythonPythonPackageContentResponse.

        Artifact file representing the physical content  # noqa: E501

        :param artifact: The artifact of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._artifact = artifact

    @property
    def filename(self):
        """Gets the filename of this PythonPythonPackageContentResponse.  # noqa: E501

        The name of the distribution package, usually of the format: {distribution}-{version}(-{build tag})?-{python tag}-{abi tag}-{platform tag}.{packagetype}  # noqa: E501

        :return: The filename of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this PythonPythonPackageContentResponse.

        The name of the distribution package, usually of the format: {distribution}-{version}(-{build tag})?-{python tag}-{abi tag}-{platform tag}.{packagetype}  # noqa: E501

        :param filename: The filename of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._filename = filename

    @property
    def packagetype(self):
        """Gets the packagetype of this PythonPythonPackageContentResponse.  # noqa: E501

        The type of the distribution package (e.g. sdist, bdist_wheel, bdist_egg, etc)  # noqa: E501

        :return: The packagetype of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._packagetype

    @packagetype.setter
    def packagetype(self, packagetype):
        """Sets the packagetype of this PythonPythonPackageContentResponse.

        The type of the distribution package (e.g. sdist, bdist_wheel, bdist_egg, etc)  # noqa: E501

        :param packagetype: The packagetype of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._packagetype = packagetype

    @property
    def name(self):
        """Gets the name of this PythonPythonPackageContentResponse.  # noqa: E501

        The name of the python project.  # noqa: E501

        :return: The name of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PythonPythonPackageContentResponse.

        The name of the python project.  # noqa: E501

        :param name: The name of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def version(self):
        """Gets the version of this PythonPythonPackageContentResponse.  # noqa: E501

        The packages version number.  # noqa: E501

        :return: The version of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PythonPythonPackageContentResponse.

        The packages version number.  # noqa: E501

        :param version: The version of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def sha256(self):
        """Gets the sha256 of this PythonPythonPackageContentResponse.  # noqa: E501

        The SHA256 digest of this package.  # noqa: E501

        :return: The sha256 of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this PythonPythonPackageContentResponse.

        The SHA256 digest of this package.  # noqa: E501

        :param sha256: The sha256 of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._sha256 = sha256

    @property
    def metadata_version(self):
        """Gets the metadata_version of this PythonPythonPackageContentResponse.  # noqa: E501

        Version of the file format  # noqa: E501

        :return: The metadata_version of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._metadata_version

    @metadata_version.setter
    def metadata_version(self, metadata_version):
        """Sets the metadata_version of this PythonPythonPackageContentResponse.

        Version of the file format  # noqa: E501

        :param metadata_version: The metadata_version of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._metadata_version = metadata_version

    @property
    def summary(self):
        """Gets the summary of this PythonPythonPackageContentResponse.  # noqa: E501

        A one-line summary of what the package does.  # noqa: E501

        :return: The summary of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this PythonPythonPackageContentResponse.

        A one-line summary of what the package does.  # noqa: E501

        :param summary: The summary of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._summary = summary

    @property
    def description(self):
        """Gets the description of this PythonPythonPackageContentResponse.  # noqa: E501

        A longer description of the package that can run to several paragraphs.  # noqa: E501

        :return: The description of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PythonPythonPackageContentResponse.

        A longer description of the package that can run to several paragraphs.  # noqa: E501

        :param description: The description of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description_content_type(self):
        """Gets the description_content_type of this PythonPythonPackageContentResponse.  # noqa: E501

        A string stating the markup syntax (if any) used in the distribution’s description, so that tools can intelligently render the description.  # noqa: E501

        :return: The description_content_type of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._description_content_type

    @description_content_type.setter
    def description_content_type(self, description_content_type):
        """Sets the description_content_type of this PythonPythonPackageContentResponse.

        A string stating the markup syntax (if any) used in the distribution’s description, so that tools can intelligently render the description.  # noqa: E501

        :param description_content_type: The description_content_type of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._description_content_type = description_content_type

    @property
    def keywords(self):
        """Gets the keywords of this PythonPythonPackageContentResponse.  # noqa: E501

        Additional keywords to be used to assist searching for the package in a larger catalog.  # noqa: E501

        :return: The keywords of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this PythonPythonPackageContentResponse.

        Additional keywords to be used to assist searching for the package in a larger catalog.  # noqa: E501

        :param keywords: The keywords of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._keywords = keywords

    @property
    def home_page(self):
        """Gets the home_page of this PythonPythonPackageContentResponse.  # noqa: E501

        The URL for the package's home page.  # noqa: E501

        :return: The home_page of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._home_page

    @home_page.setter
    def home_page(self, home_page):
        """Sets the home_page of this PythonPythonPackageContentResponse.

        The URL for the package's home page.  # noqa: E501

        :param home_page: The home_page of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._home_page = home_page

    @property
    def download_url(self):
        """Gets the download_url of this PythonPythonPackageContentResponse.  # noqa: E501

        Legacy field denoting the URL from which this package can be downloaded.  # noqa: E501

        :return: The download_url of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this PythonPythonPackageContentResponse.

        Legacy field denoting the URL from which this package can be downloaded.  # noqa: E501

        :param download_url: The download_url of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._download_url = download_url

    @property
    def author(self):
        """Gets the author of this PythonPythonPackageContentResponse.  # noqa: E501

        Text containing the author's name. Contact information can also be added, separated with newlines.  # noqa: E501

        :return: The author of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this PythonPythonPackageContentResponse.

        Text containing the author's name. Contact information can also be added, separated with newlines.  # noqa: E501

        :param author: The author of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._author = author

    @property
    def author_email(self):
        """Gets the author_email of this PythonPythonPackageContentResponse.  # noqa: E501

        The author's e-mail address.   # noqa: E501

        :return: The author_email of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._author_email

    @author_email.setter
    def author_email(self, author_email):
        """Sets the author_email of this PythonPythonPackageContentResponse.

        The author's e-mail address.   # noqa: E501

        :param author_email: The author_email of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._author_email = author_email

    @property
    def maintainer(self):
        """Gets the maintainer of this PythonPythonPackageContentResponse.  # noqa: E501

        The maintainer's name at a minimum; additional contact information may be provided.  # noqa: E501

        :return: The maintainer of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._maintainer

    @maintainer.setter
    def maintainer(self, maintainer):
        """Sets the maintainer of this PythonPythonPackageContentResponse.

        The maintainer's name at a minimum; additional contact information may be provided.  # noqa: E501

        :param maintainer: The maintainer of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._maintainer = maintainer

    @property
    def maintainer_email(self):
        """Gets the maintainer_email of this PythonPythonPackageContentResponse.  # noqa: E501

        The maintainer's e-mail address.  # noqa: E501

        :return: The maintainer_email of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._maintainer_email

    @maintainer_email.setter
    def maintainer_email(self, maintainer_email):
        """Sets the maintainer_email of this PythonPythonPackageContentResponse.

        The maintainer's e-mail address.  # noqa: E501

        :param maintainer_email: The maintainer_email of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._maintainer_email = maintainer_email

    @property
    def license(self):
        """Gets the license of this PythonPythonPackageContentResponse.  # noqa: E501

        Text indicating the license covering the distribution  # noqa: E501

        :return: The license of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this PythonPythonPackageContentResponse.

        Text indicating the license covering the distribution  # noqa: E501

        :param license: The license of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._license = license

    @property
    def requires_python(self):
        """Gets the requires_python of this PythonPythonPackageContentResponse.  # noqa: E501

        The Python version(s) that the distribution is guaranteed to be compatible with.  # noqa: E501

        :return: The requires_python of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._requires_python

    @requires_python.setter
    def requires_python(self, requires_python):
        """Sets the requires_python of this PythonPythonPackageContentResponse.

        The Python version(s) that the distribution is guaranteed to be compatible with.  # noqa: E501

        :param requires_python: The requires_python of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._requires_python = requires_python

    @property
    def project_url(self):
        """Gets the project_url of this PythonPythonPackageContentResponse.  # noqa: E501

        A browsable URL for the project and a label for it, separated by a comma.  # noqa: E501

        :return: The project_url of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_url

    @project_url.setter
    def project_url(self, project_url):
        """Sets the project_url of this PythonPythonPackageContentResponse.

        A browsable URL for the project and a label for it, separated by a comma.  # noqa: E501

        :param project_url: The project_url of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._project_url = project_url

    @property
    def project_urls(self):
        """Gets the project_urls of this PythonPythonPackageContentResponse.  # noqa: E501

        A dictionary of labels and URLs for the project.  # noqa: E501

        :return: The project_urls of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: object
        """
        return self._project_urls

    @project_urls.setter
    def project_urls(self, project_urls):
        """Sets the project_urls of this PythonPythonPackageContentResponse.

        A dictionary of labels and URLs for the project.  # noqa: E501

        :param project_urls: The project_urls of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: object
        """

        self._project_urls = project_urls

    @property
    def platform(self):
        """Gets the platform of this PythonPythonPackageContentResponse.  # noqa: E501

        A comma-separated list of platform specifications, summarizing the operating systems supported by the package.  # noqa: E501

        :return: The platform of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this PythonPythonPackageContentResponse.

        A comma-separated list of platform specifications, summarizing the operating systems supported by the package.  # noqa: E501

        :param platform: The platform of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._platform = platform

    @property
    def supported_platform(self):
        """Gets the supported_platform of this PythonPythonPackageContentResponse.  # noqa: E501

        Field to specify the OS and CPU for which the binary package was compiled.   # noqa: E501

        :return: The supported_platform of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: str
        """
        return self._supported_platform

    @supported_platform.setter
    def supported_platform(self, supported_platform):
        """Sets the supported_platform of this PythonPythonPackageContentResponse.

        Field to specify the OS and CPU for which the binary package was compiled.   # noqa: E501

        :param supported_platform: The supported_platform of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: str
        """

        self._supported_platform = supported_platform

    @property
    def requires_dist(self):
        """Gets the requires_dist of this PythonPythonPackageContentResponse.  # noqa: E501

        A JSON list containing names of some other distutils project required by this distribution.  # noqa: E501

        :return: The requires_dist of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: object
        """
        return self._requires_dist

    @requires_dist.setter
    def requires_dist(self, requires_dist):
        """Sets the requires_dist of this PythonPythonPackageContentResponse.

        A JSON list containing names of some other distutils project required by this distribution.  # noqa: E501

        :param requires_dist: The requires_dist of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: object
        """

        self._requires_dist = requires_dist

    @property
    def provides_dist(self):
        """Gets the provides_dist of this PythonPythonPackageContentResponse.  # noqa: E501

        A JSON list containing names of a Distutils project which is contained within this distribution.  # noqa: E501

        :return: The provides_dist of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: object
        """
        return self._provides_dist

    @provides_dist.setter
    def provides_dist(self, provides_dist):
        """Sets the provides_dist of this PythonPythonPackageContentResponse.

        A JSON list containing names of a Distutils project which is contained within this distribution.  # noqa: E501

        :param provides_dist: The provides_dist of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: object
        """

        self._provides_dist = provides_dist

    @property
    def obsoletes_dist(self):
        """Gets the obsoletes_dist of this PythonPythonPackageContentResponse.  # noqa: E501

        A JSON list containing names of a distutils project's distribution which this distribution renders obsolete, meaning that the two projects should not be installed at the same time.  # noqa: E501

        :return: The obsoletes_dist of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: object
        """
        return self._obsoletes_dist

    @obsoletes_dist.setter
    def obsoletes_dist(self, obsoletes_dist):
        """Sets the obsoletes_dist of this PythonPythonPackageContentResponse.

        A JSON list containing names of a distutils project's distribution which this distribution renders obsolete, meaning that the two projects should not be installed at the same time.  # noqa: E501

        :param obsoletes_dist: The obsoletes_dist of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: object
        """

        self._obsoletes_dist = obsoletes_dist

    @property
    def requires_external(self):
        """Gets the requires_external of this PythonPythonPackageContentResponse.  # noqa: E501

        A JSON list containing some dependency in the system that the distribution is to be used.  # noqa: E501

        :return: The requires_external of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: object
        """
        return self._requires_external

    @requires_external.setter
    def requires_external(self, requires_external):
        """Sets the requires_external of this PythonPythonPackageContentResponse.

        A JSON list containing some dependency in the system that the distribution is to be used.  # noqa: E501

        :param requires_external: The requires_external of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: object
        """

        self._requires_external = requires_external

    @property
    def classifiers(self):
        """Gets the classifiers of this PythonPythonPackageContentResponse.  # noqa: E501

        A JSON list containing classification values for a Python package.  # noqa: E501

        :return: The classifiers of this PythonPythonPackageContentResponse.  # noqa: E501
        :rtype: object
        """
        return self._classifiers

    @classifiers.setter
    def classifiers(self, classifiers):
        """Sets the classifiers of this PythonPythonPackageContentResponse.

        A JSON list containing classification values for a Python package.  # noqa: E501

        :param classifiers: The classifiers of this PythonPythonPackageContentResponse.  # noqa: E501
        :type: object
        """

        self._classifiers = classifiers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PythonPythonPackageContentResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PythonPythonPackageContentResponse):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pulpcore.client.pulp_python.api.content_packages_api import ContentPackagesApi
from pulpcore.client.pulp_python.api.distributions_pypi_api import DistributionsPypiApi
from pulpcore.client.pulp_python.api.publications_pypi_api import PublicationsPypiApi
from pulpcore.client.pulp_python.api.pypi_api import PypiApi
from pulpcore.client.pulp_python.api.pypi_legacy_api import PypiLegacyApi
from pulpcore.client.pulp_python.api.pypi_metadata_api import PypiMetadataApi
from pulpcore.client.pulp_python.api.pypi_simple_api import PypiSimpleApi
from pulpcore.client.pulp_python.api.remotes_python_api import RemotesPythonApi
from pulpcore.client.pulp_python.api.repositories_python_api import RepositoriesPythonApi
from pulpcore.client.pulp_python.api.repositories_python_versions_api import RepositoriesPythonVersionsApi



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pulpcore.client.pulp_python.api_client import ApiClient
from pulpcore.client.pulp_python.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ContentPackagesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create(self, relative_path, **kwargs):  # noqa: E501
        """Create a python package content  # noqa: E501

        Trigger an asynchronous task to create content,optionally create new repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(relative_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relative_path: Path where the artifact is located relative to distributions base_path (required)
        :param str artifact: Artifact file representing the physical content
        :param file file: An uploaded file that may be turned into the artifact of the content unit.
        :param str repository: A URI of a repository the new content unit should be associated with.
        :param str upload: An uncommitted upload that may be turned into the artifact of the content unit.
        :param str sha256: The SHA256 digest of this package.
        :param str summary: A one-line summary of what the package does.
        :param str description: A longer description of the package that can run to several paragraphs.
        :param str description_content_type: A string stating the markup syntax (if any) used in the distribution’s description, so that tools can intelligently render the description.
        :param str keywords: Additional keywords to be used to assist searching for the package in a larger catalog.
        :param str home_page: The URL for the package's home page.
        :param str download_url: Legacy field denoting the URL from which this package can be downloaded.
        :param str author: Text containing the author's name. Contact information can also be added, separated with newlines.
        :param str author_email: The author's e-mail address. 
        :param str maintainer: The maintainer's name at a minimum; additional contact information may be provided.
        :param str maintainer_email: The maintainer's e-mail address.
        :param str license: Text indicating the license covering the distribution
        :param str requires_python: The Python version(s) that the distribution is guaranteed to be compatible with.
        :param str project_url: A browsable URL for the project and a label for it, separated by a comma.
        :param object project_urls: A dictionary of labels and URLs for the project.
        :param str platform: A comma-separated list of platform specifications, summarizing the operating systems supported by the package.
        :param str supported_platform: Field to specify the OS and CPU for which the binary package was compiled. 
        :param object requires_dist: A JSON list containing names of some other distutils project required by this distribution.
        :param object provides_dist: A JSON list containing names of a Distutils project which is contained within this distribution.
        :param object obsoletes_dist: A JSON list containing names of a distutils project's distribution which this distribution renders obsolete, meaning that the two projects should not be installed at the same time.
        :param object requires_external: A JSON list containing some dependency in the system that the distribution is to be used.
        :param object classifiers: A JSON list containing classification values for a Python package.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AsyncOperationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_with_http_info(relative_path, **kwargs)  # noqa: E501

    def create_with_http_info(self, relative_path, **kwargs):  # noqa: E501
        """Create a python package content  # noqa: E501

        Trigger an asynchronous task to create content,optionally create new repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_with_http_info(relative_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relative_path: Path where the artifact is located relative to distributions base_path (required)
        :param str artifact: Artifact file representing the physical content
        :param file file: An uploaded file that may be turned into the artifact of the content unit.
        :param str repository: A URI of a repository the new content unit should be associated with.
        :param str upload: An uncommitted upload that may be turned into the artifact of the content unit.
        :param str sha256: The SHA256 digest of this package.
        :param str summary: A one-line summary of what the package does.
        :param str description: A longer description of the package that can run to several paragraphs.
        :param str description_content_type: A string stating the markup syntax (if any) used in the distribution’s description, so that tools can intelligently render the description.
        :param str keywords: Additional keywords to be used to assist searching for the package in a larger catalog.
        :param str home_page: The URL for the package's home page.
        :param str download_url: Legacy field denoting the URL from which this package can be downloaded.
        :param str author: Text containing the author's name. Contact information can also be added, separated with newlines.
        :param str author_email: The author's e-mail address. 
        :param str maintainer: The maintainer's name at a minimum; additional contact information may be provided.
        :param str maintainer_email: The maintainer's e-mail address.
        :param str license: Text indicating the license covering the distribution
        :param str requires_python: The Python version(s) that the distribution is guaranteed to be compatible with.
        :param str project_url: A browsable URL for the project and a label for it, separated by a comma.
        :param object project_urls: A dictionary of labels and URLs for the project.
        :param str platform: A comma-separated list of platform specifications, summarizing the operating systems supported by the package.
        :param str supported_platform: Field to specify the OS and CPU for which the binary package was compiled. 
        :param object requires_dist: A JSON list containing names of some other distutils project required by this distribution.
        :param object provides_dist: A JSON list containing names of a Distutils project which is contained within this distribution.
        :param object obsoletes_dist: A JSON list containing names of a distutils project's distribution which this distribution renders obsolete, meaning that the two projects should not be installed at the same time.
        :param object requires_external: A JSON list containing some dependency in the system that the distribution is to be used.
        :param object classifiers: A JSON list containing classification values for a Python package.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AsyncOperationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'relative_path',
            'artifact',
            'file',
            'repository',
            'upload',
            'sha256',
            'summary',
            'description',
            'description_content_type',
            'keywords',
            'home_page',
            'download_url',
            'author',
            'author_email',
            'maintainer',
            'maintainer_email',
            'license',
            'requires_python',
            'project_url',
            'project_urls',
            'platform',
            'supported_platform',
            'requires_dist',
            'provides_dist',
            'obsoletes_dist',
            'requires_external',
            'classifiers'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'relative_path' is set
        if self.api_client.client_side_validation and ('relative_path' not in local_var_params or  # noqa: E501
                                                        local_var_params['relative_path'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `relative_path` when calling `create`")  # noqa: E501

        if self.api_client.client_side_validation and ('relative_path' in local_var_params and  # noqa: E501
                                                        len(local_var_params['relative_path']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `relative_path` when calling `create`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('sha256' in local_var_params and  # noqa: E501
                                                        len(local_var_params['sha256']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `sha256` when calling `create`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'artifact' in local_var_params:
            form_params.append(('artifact', local_var_params['artifact']))  # noqa: E501
        if 'relative_path' in local_var_params:
            form_params.append(('relative_path', local_var_params['relative_path']))  # noqa: E501
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501
        if 'repository' in local_var_params:
            form_params.append(('repository', local_var_params['repository']))  # noqa: E501
        if 'upload' in local_var_params:
            form_params.append(('upload', local_var_params['upload']))  # noqa: E501
        if 'sha256' in local_var_params:
            form_params.append(('sha256', local_var_params['sha256']))  # noqa: E501
        if 'summary' in local_var_params:
            form_params.append(('summary', local_var_params['summary']))  # noqa: E501
        if 'description' in local_var_params:
            form_params.append(('description', local_var_params['description']))  # noqa: E501
        if 'description_content_type' in local_var_params:
            form_params.append(('description_content_type', local_var_params['description_content_type']))  # noqa: E501
        if 'keywords' in local_var_params:
            form_params.append(('keywords', local_var_params['keywords']))  # noqa: E501
        if 'home_page' in local_var_params:
            form_params.append(('home_page', local_var_params['home_page']))  # noqa: E501
        if 'download_url' in local_var_params:
            form_params.append(('download_url', local_var_params['download_url']))  # noqa: E501
        if 'author' in local_var_params:
            form_params.append(('author', local_var_params['author']))  # noqa: E501
        if 'author_email' in local_var_params:
            form_params.append(('author_email', local_var_params['author_email']))  # noqa: E501
        if 'maintainer' in local_var_params:
            form_params.append(('maintainer', local_var_params['maintainer']))  # noqa: E501
        if 'maintainer_email' in local_var_params:
            form_params.append(('maintainer_email', local_var_params['maintainer_email']))  # noqa: E501
        if 'license' in local_var_params:
            form_params.append(('license', local_var_params['license']))  # noqa: E501
        if 'requires_python' in local_var_params:
            form_params.append(('requires_python', local_var_params['requires_python']))  # noqa: E501
        if 'project_url' in local_var_params:
            form_params.append(('project_url', local_var_params['project_url']))  # noqa: E501
        if 'project_urls' in local_var_params:
            form_params.append(('project_urls', local_var_params['project_urls']))  # noqa: E501
        if 'platform' in local_var_params:
            form_params.append(('platform', local_var_params['platform']))  # noqa: E501
        if 'supported_platform' in local_var_params:
            form_params.append(('supported_platform', local_var_params['supported_platform']))  # noqa: E501
        if 'requires_dist' in local_var_params:
            form_params.append(('requires_dist', local_var_params['requires_dist']))  # noqa: E501
        if 'provides_dist' in local_var_params:
            form_params.append(('provides_dist', local_var_params['provides_dist']))  # noqa: E501
        if 'obsoletes_dist' in local_var_params:
            form_params.append(('obsoletes_dist', local_var_params['obsoletes_dist']))  # noqa: E501
        if 'requires_external' in local_var_params:
            form_params.append(('requires_external', local_var_params['requires_external']))  # noqa: E501
        if 'classifiers' in local_var_params:
            form_params.append(('classifiers', local_var_params['classifiers']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/content/python/packages/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsyncOperationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list(self, **kwargs):  # noqa: E501
        """List python package contents  # noqa: E501

         PythonPackageContent represents each individually installable Python package. In the Python ecosystem, this is called a Python Distribution, sometimes (ambiguously) refered to as a package. In Pulp Python, we refer to it as PythonPackageContent. Each PythonPackageContent corresponds to a single filename, for example `pulpcore-3.0.0rc1-py3-none-any.whl` or `pulpcore-3.0.0rc1.tar.gz`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str author: Filter results where author matches value
        :param list[str] author__in: Filter results where author is in a comma-separated list of values
        :param str filename: Filter results where filename matches value
        :param str filename__contains: Filter results where filename contains value
        :param list[str] filename__in: Filter results where filename is in a comma-separated list of values
        :param str keywords__contains: Filter results where keywords contains value
        :param list[str] keywords__in: Filter results where keywords is in a comma-separated list of values
        :param int limit: Number of results to return per page.
        :param str name: Filter results where name matches value
        :param list[str] name__in: Filter results where name is in a comma-separated list of values
        :param int offset: The initial index from which to return the results.
        :param list[str] ordering: Ordering
        :param str packagetype: Filter results where packagetype matches value
        :param list[str] packagetype__in: Filter results where packagetype is in a comma-separated list of values
        :param str repository_version: Repository Version referenced by HREF
        :param str repository_version_added: Repository Version referenced by HREF
        :param str repository_version_removed: Repository Version referenced by HREF
        :param str requires_python: Filter results where requires_python matches value
        :param str requires_python__contains: Filter results where requires_python contains value
        :param list[str] requires_python__in: Filter results where requires_python is in a comma-separated list of values
        :param str sha256: Filter results where sha256 matches value
        :param list[str] sha256__in: Filter results where sha256 is in a comma-separated list of values
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PaginatedpythonPythonPackageContentResponseList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_with_http_info(**kwargs)  # noqa: E501

    def list_with_http_info(self, **kwargs):  # noqa: E501
        """List python package contents  # noqa: E501

         PythonPackageContent represents each individually installable Python package. In the Python ecosystem, this is called a Python Distribution, sometimes (ambiguously) refered to as a package. In Pulp Python, we refer to it as PythonPackageContent. Each PythonPackageContent corresponds to a single filename, for example `pulpcore-3.0.0rc1-py3-none-any.whl` or `pulpcore-3.0.0rc1.tar.gz`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str author: Filter results where author matches value
        :param list[str] author__in: Filter results where author is in a comma-separated list of values
        :param str filename: Filter results where filename matches value
        :param str filename__contains: Filter results where filename contains value
        :param list[str] filename__in: Filter results where filename is in a comma-separated list of values
        :param str keywords__contains: Filter results where keywords contains value
        :param list[str] keywords__in: Filter results where keywords is in a comma-separated list of values
        :param int limit: Number of results to return per page.
        :param str name: Filter results where name matches value
        :param list[str] name__in: Filter results where name is in a comma-separated list of values
        :param int offset: The initial index from which to return the results.
        :param list[str] ordering: Ordering
        :param str packagetype: Filter results where packagetype matches value
        :param list[str] packagetype__in: Filter results where packagetype is in a comma-separated list of values
        :param str repository_version: Repository Version referenced by HREF
        :param str repository_version_added: Repository Version referenced by HREF
        :param str repository_version_removed: Repository Version referenced by HREF
        :param str requires_python: Filter results where requires_python matches value
        :param str requires_python__contains: Filter results where requires_python contains value
        :param list[str] requires_python__in: Filter results where requires_python is in a comma-separated list of values
        :param str sha256: Filter results where sha256 matches value
        :param list[str] sha256__in: Filter results where sha256 is in a comma-separated list of values
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PaginatedpythonPythonPackageContentResponseList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'author',
            'author__in',
            'filename',
            'filename__contains',
            'filename__in',
            'keywords__contains',
            'keywords__in',
            'limit',
            'name',
            'name__in',
            'offset',
            'ordering',
            'packagetype',
            'packagetype__in',
            'repository_version',
            'repository_version_added',
            'repository_version_removed',
            'requires_python',
            'requires_python__contains',
            'requires_python__in',
            'sha256',
            'sha256__in',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'author' in local_var_params and local_var_params['author'] is not None:  # noqa: E501
            query_params.append(('author', local_var_params['author']))  # noqa: E501
        if 'author__in' in local_var_params and local_var_params['author__in'] is not None:  # noqa: E501
            query_params.append(('author__in', local_var_params['author__in']))  # noqa: E501
            collection_formats['author__in'] = 'csv'  # noqa: E501
        if 'filename' in local_var_params and local_var_params['filename'] is not None:  # noqa: E501
            query_params.append(('filename', local_var_params['filename']))  # noqa: E501
        if 'filename__contains' in local_var_params and local_var_params['filename__contains'] is not None:  # noqa: E501
            query_params.append(('filename__contains', local_var_params['filename__contains']))  # noqa: E501
        if 'filename__in' in local_var_params and local_var_params['filename__in'] is not None:  # noqa: E501
            query_params.append(('filename__in', local_var_params['filename__in']))  # noqa: E501
            collection_formats['filename__in'] = 'csv'  # noqa: E501
        if 'keywords__contains' in local_var_params and local_var_params['keywords__contains'] is not None:  # noqa: E501
            query_params.append(('keywords__contains', local_var_params['keywords__contains']))  # noqa: E501
        if 'keywords__in' in local_var_params and local_var_params['keywords__in'] is not None:  # noqa: E501
            query_params.append(('keywords__in', local_var_params['keywords__in']))  # noqa: E501
            collection_formats['keywords__in'] = 'csv'  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'name__in' in local_var_params and local_var_params['name__in'] is not None:  # noqa: E501
            query_params.append(('name__in', local_var_params['name__in']))  # noqa: E501
            collection_formats['name__in'] = 'csv'  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'ordering' in local_var_params and local_var_params['ordering'] is not None:  # noqa: E501
            query_params.append(('ordering', local_var_params['ordering']))  # noqa: E501
            collection_formats['ordering'] = 'csv'  # noqa: E501
        if 'packagetype' in local_var_params and local_var_params['packagetype'] is not None:  # noqa: E501
            query_params.append(('packagetype', local_var_params['packagetype']))  # noqa: E501
        if 'packagetype__in' in local_var_params and local_var_params['packagetype__in'] is not None:  # noqa: E501
            query_params.append(('packagetype__in', local_var_params['packagetype__in']))  # noqa: E501
            collection_formats['packagetype__in'] = 'csv'  # noqa: E501
        if 'repository_version' in local_var_params and local_var_params['repository_version'] is not None:  # noqa: E501
            query_params.append(('repository_version', local_var_params['repository_version']))  # noqa: E501
        if 'repository_version_added' in local_var_params and local_var_params['repository_version_added'] is not None:  # noqa: E501
            query_params.append(('repository_version_added', local_var_params['repository_version_added']))  # noqa: E501
        if 'repository_version_removed' in local_var_params and local_var_params['repository_version_removed'] is not None:  # noqa: E501
            query_params.append(('repository_version_removed', local_var_params['repository_version_removed']))  # noqa: E501
        if 'requires_python' in local_var_params and local_var_params['requires_python'] is not None:  # noqa: E501
            query_params.append(('requires_python', local_var_params['requires_python']))  # noqa: E501
        if 'requires_python__contains' in local_var_params and local_var_params['requires_python__contains'] is not None:  # noqa: E501
            query_params.append(('requires_python__contains', local_var_params['requires_python__contains']))  # noqa: E501
        if 'requires_python__in' in local_var_params and local_var_params['requires_python__in'] is not None:  # noqa: E501
            query_params.append(('requires_python__in', local_var_params['requires_python__in']))  # noqa: E501
            collection_formats['requires_python__in'] = 'csv'  # noqa: E501
        if 'sha256' in local_var_params and local_var_params['sha256'] is not None:  # noqa: E501
            query_params.append(('sha256', local_var_params['sha256']))  # noqa: E501
        if 'sha256__in' in local_var_params and local_var_params['sha256__in'] is not None:  # noqa: E501
            query_params.append(('sha256__in', local_var_params['sha256__in']))  # noqa: E501
            collection_formats['sha256__in'] = 'csv'  # noqa: E501
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/content/python/packages/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaginatedpythonPythonPackageContentResponseList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, python_python_package_content_href, **kwargs):  # noqa: E501
        """Inspect a python package content  # noqa: E501

         PythonPackageContent represents each individually installable Python package. In the Python ecosystem, this is called a Python Distribution, sometimes (ambiguously) refered to as a package. In Pulp Python, we refer to it as PythonPackageContent. Each PythonPackageContent corresponds to a single filename, for example `pulpcore-3.0.0rc1-py3-none-any.whl` or `pulpcore-3.0.0rc1.tar.gz`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(python_python_package_content_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_package_content_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PythonPythonPackageContentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_with_http_info(python_python_package_content_href, **kwargs)  # noqa: E501

    def read_with_http_info(self, python_python_package_content_href, **kwargs):  # noqa: E501
        """Inspect a python package content  # noqa: E501

         PythonPackageContent represents each individually installable Python package. In the Python ecosystem, this is called a Python Distribution, sometimes (ambiguously) refered to as a package. In Pulp Python, we refer to it as PythonPackageContent. Each PythonPackageContent corresponds to a single filename, for example `pulpcore-3.0.0rc1-py3-none-any.whl` or `pulpcore-3.0.0rc1.tar.gz`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(python_python_package_content_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_package_content_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PythonPythonPackageContentResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'python_python_package_content_href',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'python_python_package_content_href' is set
        if self.api_client.client_side_validation and ('python_python_package_content_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['python_python_package_content_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `python_python_package_content_href` when calling `read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'python_python_package_content_href' in local_var_params:
            path_params['python_python_package_content_href'] = local_var_params['python_python_package_content_href']  # noqa: E501

        query_params = []
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{python_python_package_content_href}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PythonPythonPackageContentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_python.configuration import Configuration


class PackageMetadataResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'last_serial': 'int',
        'info': 'object',
        'releases': 'object',
        'urls': 'object'
    }

    attribute_map = {
        'last_serial': 'last_serial',
        'info': 'info',
        'releases': 'releases',
        'urls': 'urls'
    }

    def __init__(self, last_serial=None, info=None, releases=None, urls=None, local_vars_configuration=None):  # noqa: E501
        """PackageMetadataResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._last_serial = None
        self._info = None
        self._releases = None
        self._urls = None
        self.discriminator = None

        self.last_serial = last_serial
        self.info = info
        self.releases = releases
        self.urls = urls

    @property
    def last_serial(self):
        """Gets the last_serial of this PackageMetadataResponse.  # noqa: E501

        Cache value from last PyPI sync  # noqa: E501

        :return: The last_serial of this PackageMetadataResponse.  # noqa: E501
        :rtype: int
        """
        return self._last_serial

    @last_serial.setter
    def last_serial(self, last_serial):
        """Sets the last_serial of this PackageMetadataResponse.

        Cache value from last PyPI sync  # noqa: E501

        :param last_serial: The last_serial of this PackageMetadataResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and last_serial is None:  # noqa: E501
            raise ValueError("Invalid value for `last_serial`, must not be `None`")  # noqa: E501

        self._last_serial = last_serial

    @property
    def info(self):
        """Gets the info of this PackageMetadataResponse.  # noqa: E501

        Core metadata of the package  # noqa: E501

        :return: The info of this PackageMetadataResponse.  # noqa: E501
        :rtype: object
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this PackageMetadataResponse.

        Core metadata of the package  # noqa: E501

        :param info: The info of this PackageMetadataResponse.  # noqa: E501
        :type: object
        """
        if self.local_vars_configuration.client_side_validation and info is None:  # noqa: E501
            raise ValueError("Invalid value for `info`, must not be `None`")  # noqa: E501

        self._info = info

    @property
    def releases(self):
        """Gets the releases of this PackageMetadataResponse.  # noqa: E501

        List of all the releases of the package  # noqa: E501

        :return: The releases of this PackageMetadataResponse.  # noqa: E501
        :rtype: object
        """
        return self._releases

    @releases.setter
    def releases(self, releases):
        """Sets the releases of this PackageMetadataResponse.

        List of all the releases of the package  # noqa: E501

        :param releases: The releases of this PackageMetadataResponse.  # noqa: E501
        :type: object
        """
        if self.local_vars_configuration.client_side_validation and releases is None:  # noqa: E501
            raise ValueError("Invalid value for `releases`, must not be `None`")  # noqa: E501

        self._releases = releases

    @property
    def urls(self):
        """Gets the urls of this PackageMetadataResponse.  # noqa: E501


        :return: The urls of this PackageMetadataResponse.  # noqa: E501
        :rtype: object
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """Sets the urls of this PackageMetadataResponse.


        :param urls: The urls of this PackageMetadataResponse.  # noqa: E501
        :type: object
        """
        if self.local_vars_configuration.client_side_validation and urls is None:  # noqa: E501
            raise ValueError("Invalid value for `urls`, must not be `None`")  # noqa: E501

        self._urls = urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageMetadataResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PackageMetadataResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_python
from pulpcore.client.pulp_python.models.python_python_package_content_response import PythonPythonPackageContentResponse  # noqa: E501
from pulpcore.client.pulp_python.rest import ApiException

class TestPythonPythonPackageContentResponse(unittest.TestCase):
    """PythonPythonPackageContentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PythonPythonPackageContentResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_python.models.python_python_package_content_response.PythonPythonPackageContentResponse()  # noqa: E501
        if include_optional :
            return PythonPythonPackageContentResponse(
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                artifact = '0', 
                filename = '0', 
                packagetype = '0', 
                name = '0', 
                version = '0', 
                sha256 = '0', 
                metadata_version = '0', 
                summary = '0', 
                description = '0', 
                description_content_type = '0', 
                keywords = '0', 
                home_page = '0', 
                download_url = '0', 
                author = '0', 
                author_email = '0', 
                maintainer = '0', 
                maintainer_email = '0', 
                license = '0', 
                requires_python = '0', 
                project_url = '0', 
                project_urls = pulpcore.client.pulp_python.models.project_urls.project_urls(), 
                platform = '0', 
                supported_platform = '0', 
                requires_dist = pulpcore.client.pulp_python.models.requires_dist.requires_dist(), 
                provides_dist = pulpcore.client.pulp_python.models.provides_dist.provides_dist(), 
                obsoletes_dist = pulpcore.client.pulp_python.models.obsoletes_dist.obsoletes_dist(), 
                requires_external = pulpcore.client.pulp_python.models.requires_external.requires_external(), 
                classifiers = pulpcore.client.pulp_python.models.classifiers.classifiers()
            )
        else :
            return PythonPythonPackageContentResponse(
        )

    def testPythonPythonPackageContentResponse(self):
        """Test PythonPythonPackageContentResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from pulpcore.client.pulp_python.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_python.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulp_python.models.exclude_platforms_enum import ExcludePlatformsEnum
from pulpcore.client.pulp_python.models.package_metadata_response import PackageMetadataResponse
from pulpcore.client.pulp_python.models.package_types_enum import PackageTypesEnum
from pulpcore.client.pulp_python.models.package_upload import PackageUpload
from pulpcore.client.pulp_python.models.package_upload_task_response import PackageUploadTaskResponse
from pulpcore.client.pulp_python.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_distribution_response_list import PaginatedpythonPythonDistributionResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_package_content_response_list import PaginatedpythonPythonPackageContentResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_publication_response_list import PaginatedpythonPythonPublicationResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_remote_response_list import PaginatedpythonPythonRemoteResponseList
from pulpcore.client.pulp_python.models.paginatedpython_python_repository_response_list import PaginatedpythonPythonRepositoryResponseList
from pulpcore.client.pulp_python.models.patchedpython_python_distribution import PatchedpythonPythonDistribution
from pulpcore.client.pulp_python.models.patchedpython_python_remote import PatchedpythonPythonRemote
from pulpcore.client.pulp_python.models.patchedpython_python_repository import PatchedpythonPythonRepository
from pulpcore.client.pulp_python.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_python.models.python_bander_remote import PythonBanderRemote
from pulpcore.client.pulp_python.models.python_python_distribution import PythonPythonDistribution
from pulpcore.client.pulp_python.models.python_python_distribution_response import PythonPythonDistributionResponse
from pulpcore.client.pulp_python.models.python_python_package_content import PythonPythonPackageContent
from pulpcore.client.pulp_python.models.python_python_package_content_response import PythonPythonPackageContentResponse
from pulpcore.client.pulp_python.models.python_python_publication import PythonPythonPublication
from pulpcore.client.pulp_python.models.python_python_publication_response import PythonPythonPublicationResponse
from pulpcore.client.pulp_python.models.python_python_remote import PythonPythonRemote
from pulpcore.client.pulp_python.models.python_python_remote_response import PythonPythonRemoteResponse
from pulpcore.client.pulp_python.models.python_python_repository import PythonPythonRepository
from pulpcore.client.pulp_python.models.python_python_repository_response import PythonPythonRepositoryResponse
from pulpcore.client.pulp_python.models.repair import Repair
from pulpcore.client.pulp_python.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulp_python.models.repository_sync_url import RepositorySyncURL
from pulpcore.client.pulp_python.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulp_python.models.summary_response import SummaryResponse



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_python.configuration import Configuration


class PackageUpload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content': 'file',
        'action': 'str',
        'sha256_digest': 'str'
    }

    attribute_map = {
        'content': 'content',
        'action': 'action',
        'sha256_digest': 'sha256_digest'
    }

    def __init__(self, content=None, action='file_upload', sha256_digest=None, local_vars_configuration=None):  # noqa: E501
        """PackageUpload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content = None
        self._action = None
        self._sha256_digest = None
        self.discriminator = None

        self.content = content
        if action is not None:
            self.action = action
        self.sha256_digest = sha256_digest

    @property
    def content(self):
        """Gets the content of this PackageUpload.  # noqa: E501

        A Python package release file to upload to the index.  # noqa: E501

        :return: The content of this PackageUpload.  # noqa: E501
        :rtype: file
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PackageUpload.

        A Python package release file to upload to the index.  # noqa: E501

        :param content: The content of this PackageUpload.  # noqa: E501
        :type: file
        """
        if self.local_vars_configuration.client_side_validation and content is None:  # noqa: E501
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def action(self):
        """Gets the action of this PackageUpload.  # noqa: E501

        Defaults to `file_upload`, don't change it or request will fail!  # noqa: E501

        :return: The action of this PackageUpload.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this PackageUpload.

        Defaults to `file_upload`, don't change it or request will fail!  # noqa: E501

        :param action: The action of this PackageUpload.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                action is not None and len(action) < 1):
            raise ValueError("Invalid value for `action`, length must be greater than or equal to `1`")  # noqa: E501

        self._action = action

    @property
    def sha256_digest(self):
        """Gets the sha256_digest of this PackageUpload.  # noqa: E501

        SHA256 of package to validate upload integrity.  # noqa: E501

        :return: The sha256_digest of this PackageUpload.  # noqa: E501
        :rtype: str
        """
        return self._sha256_digest

    @sha256_digest.setter
    def sha256_digest(self, sha256_digest):
        """Sets the sha256_digest of this PackageUpload.

        SHA256 of package to validate upload integrity.  # noqa: E501

        :param sha256_digest: The sha256_digest of this PackageUpload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sha256_digest is None:  # noqa: E501
            raise ValueError("Invalid value for `sha256_digest`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                sha256_digest is not None and len(sha256_digest) > 64):
            raise ValueError("Invalid value for `sha256_digest`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                sha256_digest is not None and len(sha256_digest) < 64):
            raise ValueError("Invalid value for `sha256_digest`, length must be greater than or equal to `64`")  # noqa: E501

        self._sha256_digest = sha256_digest

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageUpload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PackageUpload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_python
from pulpcore.client.pulp_python.models.paginatedpython_python_package_content_response_list import PaginatedpythonPythonPackageContentResponseList  # noqa: E501
from pulpcore.client.pulp_python.rest import ApiException

class TestPaginatedpythonPythonPackageContentResponseList(unittest.TestCase):
    """PaginatedpythonPythonPackageContentResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedpythonPythonPackageContentResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_python.models.paginatedpython_python_package_content_response_list.PaginatedpythonPythonPackageContentResponseList()  # noqa: E501
        if include_optional :
            return PaginatedpythonPythonPackageContentResponseList(
                count = 123, 
                next = 'http://api.example.org/accounts/?offset=400&limit=100', 
                previous = 'http://api.example.org/accounts/?offset=200&limit=100', 
                results = [
                    pulpcore.client.pulp_python.models.python/python_package_content_response.python.PythonPackageContentResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        artifact = '0', 
                        filename = '0', 
                        packagetype = '0', 
                        name = '0', 
                        version = '0', 
                        sha256 = '0', 
                        metadata_version = '0', 
                        summary = '0', 
                        description = '0', 
                        description_content_type = '0', 
                        keywords = '0', 
                        home_page = '0', 
                        download_url = '0', 
                        author = '0', 
                        author_email = '0', 
                        maintainer = '0', 
                        maintainer_email = '0', 
                        license = '0', 
                        requires_python = '0', 
                        project_url = '0', 
                        project_urls = pulpcore.client.pulp_python.models.project_urls.project_urls(), 
                        platform = '0', 
                        supported_platform = '0', 
                        requires_dist = pulpcore.client.pulp_python.models.requires_dist.requires_dist(), 
                        provides_dist = pulpcore.client.pulp_python.models.provides_dist.provides_dist(), 
                        obsoletes_dist = pulpcore.client.pulp_python.models.obsoletes_dist.obsoletes_dist(), 
                        requires_external = pulpcore.client.pulp_python.models.requires_external.requires_external(), 
                        classifiers = pulpcore.client.pulp_python.models.classifiers.classifiers(), )
                    ]
            )
        else :
            return PaginatedpythonPythonPackageContentResponseList(
        )

    def testPaginatedpythonPythonPackageContentResponseList(self):
        """Test PaginatedpythonPythonPackageContentResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pulpcore.client.pulp_python.api_client import ApiClient
from pulpcore.client.pulp_python.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DistributionsPypiApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create(self, python_python_distribution, **kwargs):  # noqa: E501
        """Create a python distribution  # noqa: E501

        Trigger an asynchronous create task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(python_python_distribution, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PythonPythonDistribution python_python_distribution: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AsyncOperationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_with_http_info(python_python_distribution, **kwargs)  # noqa: E501

    def create_with_http_info(self, python_python_distribution, **kwargs):  # noqa: E501
        """Create a python distribution  # noqa: E501

        Trigger an asynchronous create task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_with_http_info(python_python_distribution, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PythonPythonDistribution python_python_distribution: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AsyncOperationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'python_python_distribution'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'python_python_distribution' is set
        if self.api_client.client_side_validation and ('python_python_distribution' not in local_var_params or  # noqa: E501
                                                        local_var_params['python_python_distribution'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `python_python_distribution` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'python_python_distribution' in local_var_params:
            body_params = local_var_params['python_python_distribution']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/distributions/python/pypi/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsyncOperationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete(self, python_python_distribution_href, **kwargs):  # noqa: E501
        """Delete a python distribution  # noqa: E501

        Trigger an asynchronous delete task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete(python_python_distribution_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_distribution_href: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AsyncOperationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_with_http_info(python_python_distribution_href, **kwargs)  # noqa: E501

    def delete_with_http_info(self, python_python_distribution_href, **kwargs):  # noqa: E501
        """Delete a python distribution  # noqa: E501

        Trigger an asynchronous delete task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_with_http_info(python_python_distribution_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_distribution_href: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AsyncOperationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'python_python_distribution_href'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'python_python_distribution_href' is set
        if self.api_client.client_side_validation and ('python_python_distribution_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['python_python_distribution_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `python_python_distribution_href` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'python_python_distribution_href' in local_var_params:
            path_params['python_python_distribution_href'] = local_var_params['python_python_distribution_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{python_python_distribution_href}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsyncOperationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list(self, **kwargs):  # noqa: E501
        """List python distributions  # noqa: E501

         Pulp Python Distributions are used to distribute Python content from Python Repositories or Python Publications.  Pulp Python Distributions should not be confused with \"Python Distribution\" as defined by the Python community. In Pulp usage, Python content is referred to as Python Package Content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str base_path:
        :param str base_path__contains: Filter results where base_path contains value
        :param str base_path__icontains: Filter results where base_path contains value
        :param list[str] base_path__in: Filter results where base_path is in a comma-separated list of values
        :param int limit: Number of results to return per page.
        :param str name:
        :param str name__contains: Filter results where name contains value
        :param str name__icontains: Filter results where name contains value
        :param list[str] name__in: Filter results where name is in a comma-separated list of values
        :param str name__startswith: Filter results where name starts with value
        :param int offset: The initial index from which to return the results.
        :param list[str] ordering: Ordering
        :param str pulp_label_select: Filter labels by search string
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PaginatedpythonPythonDistributionResponseList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_with_http_info(**kwargs)  # noqa: E501

    def list_with_http_info(self, **kwargs):  # noqa: E501
        """List python distributions  # noqa: E501

         Pulp Python Distributions are used to distribute Python content from Python Repositories or Python Publications.  Pulp Python Distributions should not be confused with \"Python Distribution\" as defined by the Python community. In Pulp usage, Python content is referred to as Python Package Content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str base_path:
        :param str base_path__contains: Filter results where base_path contains value
        :param str base_path__icontains: Filter results where base_path contains value
        :param list[str] base_path__in: Filter results where base_path is in a comma-separated list of values
        :param int limit: Number of results to return per page.
        :param str name:
        :param str name__contains: Filter results where name contains value
        :param str name__icontains: Filter results where name contains value
        :param list[str] name__in: Filter results where name is in a comma-separated list of values
        :param str name__startswith: Filter results where name starts with value
        :param int offset: The initial index from which to return the results.
        :param list[str] ordering: Ordering
        :param str pulp_label_select: Filter labels by search string
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PaginatedpythonPythonDistributionResponseList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'base_path',
            'base_path__contains',
            'base_path__icontains',
            'base_path__in',
            'limit',
            'name',
            'name__contains',
            'name__icontains',
            'name__in',
            'name__startswith',
            'offset',
            'ordering',
            'pulp_label_select',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'base_path' in local_var_params and local_var_params['base_path'] is not None:  # noqa: E501
            query_params.append(('base_path', local_var_params['base_path']))  # noqa: E501
        if 'base_path__contains' in local_var_params and local_var_params['base_path__contains'] is not None:  # noqa: E501
            query_params.append(('base_path__contains', local_var_params['base_path__contains']))  # noqa: E501
        if 'base_path__icontains' in local_var_params and local_var_params['base_path__icontains'] is not None:  # noqa: E501
            query_params.append(('base_path__icontains', local_var_params['base_path__icontains']))  # noqa: E501
        if 'base_path__in' in local_var_params and local_var_params['base_path__in'] is not None:  # noqa: E501
            query_params.append(('base_path__in', local_var_params['base_path__in']))  # noqa: E501
            collection_formats['base_path__in'] = 'csv'  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'name__contains' in local_var_params and local_var_params['name__contains'] is not None:  # noqa: E501
            query_params.append(('name__contains', local_var_params['name__contains']))  # noqa: E501
        if 'name__icontains' in local_var_params and local_var_params['name__icontains'] is not None:  # noqa: E501
            query_params.append(('name__icontains', local_var_params['name__icontains']))  # noqa: E501
        if 'name__in' in local_var_params and local_var_params['name__in'] is not None:  # noqa: E501
            query_params.append(('name__in', local_var_params['name__in']))  # noqa: E501
            collection_formats['name__in'] = 'csv'  # noqa: E501
        if 'name__startswith' in local_var_params and local_var_params['name__startswith'] is not None:  # noqa: E501
            query_params.append(('name__startswith', local_var_params['name__startswith']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'ordering' in local_var_params and local_var_params['ordering'] is not None:  # noqa: E501
            query_params.append(('ordering', local_var_params['ordering']))  # noqa: E501
            collection_formats['ordering'] = 'csv'  # noqa: E501
        if 'pulp_label_select' in local_var_params and local_var_params['pulp_label_select'] is not None:  # noqa: E501
            query_params.append(('pulp_label_select', local_var_params['pulp_label_select']))  # noqa: E501
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/distributions/python/pypi/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaginatedpythonPythonDistributionResponseList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def partial_update(self, python_python_distribution_href, patchedpython_python_distribution, **kwargs):  # noqa: E501
        """Update a python distribution  # noqa: E501

        Trigger an asynchronous partial update task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.partial_update(python_python_distribution_href, patchedpython_python_distribution, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_distribution_href: (required)
        :param PatchedpythonPythonDistribution patchedpython_python_distribution: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AsyncOperationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.partial_update_with_http_info(python_python_distribution_href, patchedpython_python_distribution, **kwargs)  # noqa: E501

    def partial_update_with_http_info(self, python_python_distribution_href, patchedpython_python_distribution, **kwargs):  # noqa: E501
        """Update a python distribution  # noqa: E501

        Trigger an asynchronous partial update task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.partial_update_with_http_info(python_python_distribution_href, patchedpython_python_distribution, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_distribution_href: (required)
        :param PatchedpythonPythonDistribution patchedpython_python_distribution: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AsyncOperationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'python_python_distribution_href',
            'patchedpython_python_distribution'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method partial_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'python_python_distribution_href' is set
        if self.api_client.client_side_validation and ('python_python_distribution_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['python_python_distribution_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `python_python_distribution_href` when calling `partial_update`")  # noqa: E501
        # verify the required parameter 'patchedpython_python_distribution' is set
        if self.api_client.client_side_validation and ('patchedpython_python_distribution' not in local_var_params or  # noqa: E501
                                                        local_var_params['patchedpython_python_distribution'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `patchedpython_python_distribution` when calling `partial_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'python_python_distribution_href' in local_var_params:
            path_params['python_python_distribution_href'] = local_var_params['python_python_distribution_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'patchedpython_python_distribution' in local_var_params:
            body_params = local_var_params['patchedpython_python_distribution']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{python_python_distribution_href}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsyncOperationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, python_python_distribution_href, **kwargs):  # noqa: E501
        """Inspect a python distribution  # noqa: E501

         Pulp Python Distributions are used to distribute Python content from Python Repositories or Python Publications.  Pulp Python Distributions should not be confused with \"Python Distribution\" as defined by the Python community. In Pulp usage, Python content is referred to as Python Package Content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(python_python_distribution_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_distribution_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PythonPythonDistributionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_with_http_info(python_python_distribution_href, **kwargs)  # noqa: E501

    def read_with_http_info(self, python_python_distribution_href, **kwargs):  # noqa: E501
        """Inspect a python distribution  # noqa: E501

         Pulp Python Distributions are used to distribute Python content from Python Repositories or Python Publications.  Pulp Python Distributions should not be confused with \"Python Distribution\" as defined by the Python community. In Pulp usage, Python content is referred to as Python Package Content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(python_python_distribution_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_distribution_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PythonPythonDistributionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'python_python_distribution_href',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'python_python_distribution_href' is set
        if self.api_client.client_side_validation and ('python_python_distribution_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['python_python_distribution_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `python_python_distribution_href` when calling `read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'python_python_distribution_href' in local_var_params:
            path_params['python_python_distribution_href'] = local_var_params['python_python_distribution_href']  # noqa: E501

        query_params = []
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{python_python_distribution_href}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PythonPythonDistributionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update(self, python_python_distribution_href, python_python_distribution, **kwargs):  # noqa: E501
        """Update a python distribution  # noqa: E501

        Trigger an asynchronous update task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update(python_python_distribution_href, python_python_distribution, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_distribution_href: (required)
        :param PythonPythonDistribution python_python_distribution: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AsyncOperationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_with_http_info(python_python_distribution_href, python_python_distribution, **kwargs)  # noqa: E501

    def update_with_http_info(self, python_python_distribution_href, python_python_distribution, **kwargs):  # noqa: E501
        """Update a python distribution  # noqa: E501

        Trigger an asynchronous update task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_with_http_info(python_python_distribution_href, python_python_distribution, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str python_python_distribution_href: (required)
        :param PythonPythonDistribution python_python_distribution: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AsyncOperationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'python_python_distribution_href',
            'python_python_distribution'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'python_python_distribution_href' is set
        if self.api_client.client_side_validation and ('python_python_distribution_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['python_python_distribution_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `python_python_distribution_href` when calling `update`")  # noqa: E501
        # verify the required parameter 'python_python_distribution' is set
        if self.api_client.client_side_validation and ('python_python_distribution' not in local_var_params or  # noqa: E501
                                                        local_var_params['python_python_distribution'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `python_python_distribution` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'python_python_distribution_href' in local_var_params:
            path_params['python_python_distribution_href'] = local_var_params['python_python_distribution_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'python_python_distribution' in local_var_params:
            body_params = local_var_params['python_python_distribution']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{python_python_distribution_href}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsyncOperationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
